@@ -121,9 +121,10 @@ class GoogleCodeWikiComment(object):
 
 
 class GoogleCodeWikiPage(object):
-    def __init__(self, name, url):
+    def __init__(self, name, url, project_name):
         self.name = name
         self.url = url
+        self.project_name = project_name
         self.page = BeautifulSoup(urllib2.urlopen(self.url))
 
     def rewrite_wiki_links(self, text):
@@ -133,11 +134,36 @@ class GoogleCodeWikiPage(object):
             return u'[{0}]({1})'.format(match.group(1), match.group(2))
         return re.sub(pat, repl, text)
 
+    def rewrite_issue_links(self, text):
+        pat = r'\[([^\]]+)\]\(/p/([^/]+)/issues/detail\?id=([^\)]+)\)'
+        def repl(match):
+            text, project, issue = match.groups()
+            if project == self.project_name:
+                repl_pat = u'[{text}](#{issue})'
+            else:
+                repl_pat = u'[{text}](https://code.google.com/p/{project}/issues/detail?id={issue})'
+            return repl_pat.format(text=text, project=project, issue=issue)
+        return re.sub(pat, repl, text)
+
+    def rewrite_source_links(self, text):
+        pat = r'\[([^\]]+)\]\(/p/([^/]+)/source/detail\?r=([^\)]+)\)'
+        def repl(match):
+            text, project, rev = match.groups()
+            if project == self.project_name:
+                repl_pat = u'[r{rev}]'
+            else:
+                repl_pat = u'[{text}](https://code.google.com/p/{project}/source/detail?r={rev})'
+            return repl_pat.format(text=text, project=project, rev=rev)
+        return re.sub(pat, repl, text)
+
     @LazyProperty
     def text(self):
         wiki_content = self.page.find(id='wikimaincol')
         orig = html2text.HTML2Text().handle(unicode(wiki_content))
-        return self.rewrite_wiki_links(orig)
+        orig = self.rewrite_wiki_links(orig)
+        orig = self.rewrite_issue_links(orig)
+        orig = self.rewrite_source_links(orig)
+        return orig
 
     @LazyProperty
     def timestamp(self):
@@ -189,12 +215,15 @@ class GoogleCodeWikiExtractor(GoogleCodeProjectExtractor):
 
 
 class GoogleCodeWikiImporter(ToolImporter):
-    target_app = ForgeWikiApp
     source = 'Google Code'
     controller = GoogleCodeWikiImportController
     tool_label = 'Wiki'
     tool_description = 'Import your wiki pages from Google Code'
 
+    @property
+    def target_app(self):
+        return g.entry_points['tool']['wiki']
+
     def import_tool(self, project, user, project_name=None, mount_point=None,
             mount_label=None, **kw):
         """ Import a Google Code wiki into a new ForgeWiki app.
@@ -237,7 +266,7 @@ class GoogleCodeWikiImporter(ToolImporter):
 
     def get_pages(self, extractor):
         for name, url in extractor.get_wiki_pages():
-            yield GoogleCodeWikiPage(name, url)
+            yield GoogleCodeWikiPage(name, url, extractor.project_name)
 
     def create_page(self, page):
         global c
